@@ -1,4 +1,4 @@
-/*      $Id: shortcuts_plugin.c 22152 2006-06-18 16:17:04Z pollux $
+/*      $Id: shortcuts_plugin.c 22694 2006-08-09 12:01:02Z pollux $
  *
  * Copyright (c) 2006 Jean-Francois Wauthy <pollux@xfce.org>
  *                    Olivier Fourdan <fourdan@xfce.org>
@@ -1111,7 +1111,7 @@ cb_treeview_shortcuts_activate (GtkWidget * treeview, GtkTreePath * path, GtkTre
         gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
 
         hbox_entry = gtk_hbox_new (FALSE, BORDER);
-        gtk_box_pack_start (GTK_BOX (hbox_entry), entry, FALSE, FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (hbox_entry), entry, TRUE, TRUE, 0);
         img = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_BUTTON);
         button = gtk_button_new ();
         gtk_container_add (GTK_CONTAINER (button), img);
@@ -1120,7 +1120,7 @@ cb_treeview_shortcuts_activate (GtkWidget * treeview, GtkTreePath * path, GtkTre
 
         hbox = gtk_hbox_new (FALSE, BORDER);
         gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
-        gtk_box_pack_start (GTK_BOX (hbox), hbox_entry, FALSE, TRUE, 0);
+        gtk_box_pack_start (GTK_BOX (hbox), hbox_entry, TRUE, TRUE, 0);
         gtk_container_set_border_width (GTK_CONTAINER (hbox), BORDER);
 
         gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_command)->vbox), hbox, FALSE, TRUE, 0);
@@ -1173,7 +1173,7 @@ cb_treeview_shortcuts_activate (GtkWidget * treeview, GtkTreePath * path, GtkTre
             g_free (launcher_data);
         }
 
-        dialog_text = g_strdup_printf ("<i>%s</i>\n<b>%s</b>", _("Set shortcut for command:"), command);
+        dialog_text = g_markup_printf_escaped ("<i>%s</i>\n<b>%s</b>", _("Set shortcut for command:"), command);
 
         /* Create dialog */
         dialog_compose = gtk_dialog_new_with_buttons (_("Set shortcut"), 
@@ -1197,7 +1197,7 @@ cb_treeview_shortcuts_activate (GtkWidget * treeview, GtkTreePath * path, GtkTre
         }
 
         label = gtk_label_new (dialog_text);
-        gtk_label_set_markup (GTK_LABEL (label), dialog_text);
+        gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
         gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
         gtk_widget_show (label);
         gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
